/*! \file EigenDataContainer.h
 *  \brief Eigen typedefs for use with the TriangleMesh
 */

#ifndef __INCLUDEFROMEIGEN_H
#define __INCLUDEFROMEIGEN_H

#include <Eigen/Dense>
#include <Eigen/Sparse>

//! \brief Contains typedefs of several Eigen data structures
struct DataTypeContainerShellFE {
public:
	typedef double RealType;
	typedef Eigen::Vector2d DomVecType;
	typedef Eigen::Vector3d TangentVecType;
	typedef Eigen::Vector3d Point3DType;
	typedef Eigen::Vector3i Indices3DType;

	typedef Eigen::Matrix<double, 2, 2> Matrix22;
	typedef Eigen::Matrix<double, 3, 2> Matrix32;
	typedef Eigen::Matrix<double, 3, 3> Matrix33;

	typedef Eigen::VectorXd  VectorType;

	typedef std::vector<bool>  MaskType;

	typedef Eigen::MatrixXd FullMatrixType;
	typedef Eigen::SparseMatrix<double, 0, long int> SparseMatrixType;
	typedef Eigen::Triplet<RealType> TripletType;
};

#endif // __EIGENINCLUDE_H
